from typing import Optional, List, Literal
from ninja import Schema


class SetSerial(Schema):
    serial_key: str


class ServerSchema(Schema):
    server_id: str
    name: str
    ping: int
    selected: bool


class ConfigSchema(Schema):
    ip: str
    location: str
    dns: str
    gateway: str
    selected_server: Optional[ServerSchema]
    is_activated: Optional[bool]
    is_connected: Optional[bool]


class UpdateConfigSchema(Schema):
    ip: Optional[str]
    location: Optional[str]
    dns: Optional[str]
    gateway: Optional[str]
    selected_server_id: Optional[str]
    is_activated: Optional[bool]
    is_connected: Optional[bool]


class SelectServerSchema(Schema):
    server_id: str


class StartServiceResponse(Schema):
    message: str
    output: Optional[str]
    error: Optional[str]


class DisconnectServiceResponse(Schema):
    message: str
    output: Optional[str] = None
    error: Optional[str] = None


class RestartServiceResponse(Schema):
    message: str
    output: Optional[str] = None
    error: Optional[str] = None


class AuthSchema(Schema):
    username: str
    password: str


class AuthResponse(Schema):
    access: str
    refresh: str


class UpdateUserSchema(Schema):
    current_password: str
    username: Optional[str] = None
    password: Optional[str] = None


class HostapdConfig(Schema):
    interface: Optional[str]
    driver: Optional[str]
    ssid: Optional[str]
    hw_mode: Optional[str]  # a, b, g (для диапазона сети)
    channel: Optional[int]
    wmm_enabled: Optional[bool]
    macaddr_acl: Optional[int]
    auth_algs: Optional[int]
    ignore_broadcast_ssid: Optional[bool]
    wpa: Optional[int]
    wpa_passphrase: Optional[str]
    wpa_key_mgmt: Optional[str]
    rsn_pairwise: Optional[str]
    network_mode: Optional[str]  # Сетевой режим (например, b/g/n)
    transmit_power: Optional[int]  # Мощность передатчика
    encryption: Optional[str]  # Тип шифрования (WPA2, WPA3 и т.д.)
    frequency: Optional[str]
    enabled: Optional[bool]


class NetworkConfigSchema(Schema):
    interface: str
    ssid: str
    hw_mode: str
    channel: int
    wpa: int
    wpa_passphrase: str


class WiFiStatusSchema(Schema):
    id: int
    band: str
    frequency: str
    transmit_power: float
    enabled: bool
    network_config: NetworkConfigSchema


class UpdateWiFiStatusSchema(Schema):
    enabled: bool


class WorkProfileSchema(Schema):
    id: int
    name: str
    profile_type: str
    is_active: bool
    selected_urls: List[str]
    selected_apps: List[str]


class CreateProfileSchema(Schema):
    name: str
    profile_type: Literal["no_restriction", "selection_mode", "exclusion_mode"]
    is_active: bool
    selected_urls: List[str]
    selected_apps: List[str]


class ProfileURLSchema(Schema):
    id: int
    url: str


class ApplicationSchema(Schema):
    id: int
    name: str


class UpdateStatusResponse(Schema):
    updates_available: bool


class UpdateResponse(Schema):
    success: bool
    output: str
